@@ -3,7 +3,8 @@
 
     This file is part of qgpgme, the Qt API binding for gpgme
     Copyright (c) 2010 Klarälvdalens Datakonsult AB
-    Copyright (c) 2016 Intevation GmbH
+    Copyright (c) 2016 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     QGpgME is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -48,7 +49,9 @@
 
 #include <sstream>
 #include <string>
+#include <functional>
 #include <cassert>
+#include <functional>
 
 using namespace QGpgME;
 using namespace GpgME;
@@ -216,17 +219,12 @@ QGpgMENewCryptoConfigGroup *QGpgMENewCryptoConfigComponent::group(const QString
 
 void QGpgMENewCryptoConfigComponent::sync(bool runtime)
 {
-    Q_UNUSED(runtime)
-    // ### how to pass --runtime to gpgconf? -> marcus: not yet supported (2010-11-20)
+    Q_UNUSED(runtime) // runtime is always set by engine_gpgconf
     if (const Error err = m_component.save()) {
-#if 0
-        TODO port
-        const QString wmsg = i18n("Error from gpgconf while saving configuration: %1", QString::fromLocal8Bit(err.asString()));
-        qCWarning(GPGPME_BACKEND_LOG) << ":" << wmsg;
-        KMessageBox::error(0, wmsg);
-#endif
+        qCWarning(GPGPME_BACKEND_LOG) << ":"
+            << "Error from gpgconf while saving configuration: %1"
+            << QString::fromLocal8Bit(err.asString());
     }
-    // ### unset dirty state again
 }
 
 ////
@@ -551,6 +549,18 @@ std::vector<unsigned int> QGpgMENewCryptoConfigEntry::uintValueList() const
     return m_option.currentValue().uintValues();
 }
 
+QStringList QGpgMENewCryptoConfigEntry::stringValueList() const
+{
+    Q_ASSERT(isList());
+    const Argument arg = m_option.currentValue();
+    const std::vector<const char *> values = arg.stringValues();
+    QStringList ret;
+    for(const char *value: values) {
+        ret << QString::fromUtf8(value);
+    }
+    return ret;
+}
+
 QList<QUrl> QGpgMENewCryptoConfigEntry::urlValueList() const
 {
     const Type type = m_option.type();
